/* Copyright (c) 2017, The Linux Foundation. All rights reserved.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2 and
 * only version 2 as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 */

#ifndef _CAM_SENSOR_ADAPTIVE_MIPI_IMX682_H_
#define _CAM_SENSOR_ADAPTIVE_MIPI_IMX682_H_

#include "cam_sensor_dev.h"

/*
SET A : Full Remosaic/RAW(4:3)	9248x6936	15fps
SET B : 2x2 Binning(4:3)	    4624x3468	30fps
SET B : 2x2 Binning(4:3)	    4624x2604	30fps
SET B : 2x2 Binning(4:3)        4000x3000   30fps
SET B : FASTAEC                 2304x1728   120fps
SET C : HFR              	    2000x1128	240fps
*/

enum {
    CAM_IMX682_SET_A_Full_1708p8_MHZ = 0,
    CAM_IMX682_SET_A_Full_1849p6_MHZ = 1,
};

struct cam_sensor_i2c_reg_array MIPI_A_1708p8_MHZ_REG_ARRAY[] = {
    {0x030F, 0x0B, 0x00, 0x00}
};

struct cam_sensor_i2c_reg_array MIPI_A_1849p6_MHZ_REG_ARRAY[] = {
    {0x030F, 0x21, 0x00, 0x00}
};

static const struct cam_sensor_i2c_reg_setting sensor_imx682_setfile_A_1708p8_mhz[] = {
    { MIPI_A_1708p8_MHZ_REG_ARRAY, ARRAY_SIZE(MIPI_A_1708p8_MHZ_REG_ARRAY),
      CAMERA_SENSOR_I2C_TYPE_WORD, CAMERA_SENSOR_I2C_TYPE_BYTE, 0 }
};

static const struct cam_sensor_i2c_reg_setting sensor_imx682_setfile_A_1849p6_mhz[] = {
    { MIPI_A_1849p6_MHZ_REG_ARRAY, ARRAY_SIZE(MIPI_A_1849p6_MHZ_REG_ARRAY),
      CAMERA_SENSOR_I2C_TYPE_WORD, CAMERA_SENSOR_I2C_TYPE_BYTE, 0 }
};

static const struct cam_mipi_setting sensor_imx682_setfile_A_mipi_setting[] = {
    { "1708.8 Mhz",
      sensor_imx682_setfile_A_1708p8_mhz, ARRAY_SIZE(sensor_imx682_setfile_A_1708p8_mhz) },
    { "1849.6 Mhz",
      sensor_imx682_setfile_A_1849p6_mhz, ARRAY_SIZE(sensor_imx682_setfile_A_1849p6_mhz) },
};

static const struct cam_mipi_channel sensor_imx682_setfile_A_channel[] = {
{ CAM_RAT_BAND(CAM_RAT_1_GSM, CAM_BAND_001_GSM_GSM850), 0, 0, CAM_IMX682_SET_A_Full_1708p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_1_GSM, CAM_BAND_002_GSM_EGSM900), 0, 0, CAM_IMX682_SET_A_Full_1708p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_1_GSM, CAM_BAND_003_GSM_DCS1800), 0, 0, CAM_IMX682_SET_A_Full_1708p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_1_GSM, CAM_BAND_004_GSM_PCS1900), 0, 0, CAM_IMX682_SET_A_Full_1849p6_MHZ },
{ CAM_RAT_BAND(CAM_RAT_2_WCDMA, CAM_BAND_011_WCDMA_WB01), 10562, 10613, CAM_IMX682_SET_A_Full_1849p6_MHZ },
{ CAM_RAT_BAND(CAM_RAT_2_WCDMA, CAM_BAND_011_WCDMA_WB01), 10614, 10644, CAM_IMX682_SET_A_Full_1708p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_2_WCDMA, CAM_BAND_011_WCDMA_WB01), 10645, 10714, CAM_IMX682_SET_A_Full_1849p6_MHZ },
{ CAM_RAT_BAND(CAM_RAT_2_WCDMA, CAM_BAND_011_WCDMA_WB01), 10715, 10746, CAM_IMX682_SET_A_Full_1708p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_2_WCDMA, CAM_BAND_011_WCDMA_WB01), 10747, 10785, CAM_IMX682_SET_A_Full_1849p6_MHZ },
{ CAM_RAT_BAND(CAM_RAT_2_WCDMA, CAM_BAND_011_WCDMA_WB01), 10786, 10838, CAM_IMX682_SET_A_Full_1708p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_2_WCDMA, CAM_BAND_012_WCDMA_WB02), 9662, 9729, CAM_IMX682_SET_A_Full_1708p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_2_WCDMA, CAM_BAND_012_WCDMA_WB02), 9730, 9799, CAM_IMX682_SET_A_Full_1849p6_MHZ },
{ CAM_RAT_BAND(CAM_RAT_2_WCDMA, CAM_BAND_012_WCDMA_WB02), 9800, 9938, CAM_IMX682_SET_A_Full_1708p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_2_WCDMA, CAM_BAND_013_WCDMA_WB03), 1162, 1244, CAM_IMX682_SET_A_Full_1708p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_2_WCDMA, CAM_BAND_013_WCDMA_WB03), 1245, 1314, CAM_IMX682_SET_A_Full_1849p6_MHZ },
{ CAM_RAT_BAND(CAM_RAT_2_WCDMA, CAM_BAND_013_WCDMA_WB03), 1315, 1447, CAM_IMX682_SET_A_Full_1708p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_2_WCDMA, CAM_BAND_013_WCDMA_WB03), 1448, 1513, CAM_IMX682_SET_A_Full_1849p6_MHZ },
{ CAM_RAT_BAND(CAM_RAT_2_WCDMA, CAM_BAND_014_WCDMA_WB04), 1537, 1588, CAM_IMX682_SET_A_Full_1849p6_MHZ },
{ CAM_RAT_BAND(CAM_RAT_2_WCDMA, CAM_BAND_014_WCDMA_WB04), 1589, 1619, CAM_IMX682_SET_A_Full_1708p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_2_WCDMA, CAM_BAND_014_WCDMA_WB04), 1620, 1689, CAM_IMX682_SET_A_Full_1849p6_MHZ },
{ CAM_RAT_BAND(CAM_RAT_2_WCDMA, CAM_BAND_014_WCDMA_WB04), 1690, 1721, CAM_IMX682_SET_A_Full_1708p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_2_WCDMA, CAM_BAND_014_WCDMA_WB04), 1722, 1738, CAM_IMX682_SET_A_Full_1849p6_MHZ },
{ CAM_RAT_BAND(CAM_RAT_2_WCDMA, CAM_BAND_015_WCDMA_WB05), 4357, 4440, CAM_IMX682_SET_A_Full_1708p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_2_WCDMA, CAM_BAND_015_WCDMA_WB05), 4441, 4458, CAM_IMX682_SET_A_Full_1849p6_MHZ },
{ CAM_RAT_BAND(CAM_RAT_2_WCDMA, CAM_BAND_017_WCDMA_WB07), 2237, 2342, CAM_IMX682_SET_A_Full_1708p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_2_WCDMA, CAM_BAND_017_WCDMA_WB07), 2343, 2382, CAM_IMX682_SET_A_Full_1849p6_MHZ },
{ CAM_RAT_BAND(CAM_RAT_2_WCDMA, CAM_BAND_017_WCDMA_WB07), 2383, 2516, CAM_IMX682_SET_A_Full_1708p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_2_WCDMA, CAM_BAND_017_WCDMA_WB07), 2517, 2563, CAM_IMX682_SET_A_Full_1849p6_MHZ },
{ CAM_RAT_BAND(CAM_RAT_2_WCDMA, CAM_BAND_018_WCDMA_WB08), 2937, 2951, CAM_IMX682_SET_A_Full_1708p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_2_WCDMA, CAM_BAND_018_WCDMA_WB08), 2952, 3013, CAM_IMX682_SET_A_Full_1849p6_MHZ },
{ CAM_RAT_BAND(CAM_RAT_2_WCDMA, CAM_BAND_018_WCDMA_WB08), 3014, 3088, CAM_IMX682_SET_A_Full_1708p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_091_LTE_LB01), 0, 126, CAM_IMX682_SET_A_Full_1849p6_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_091_LTE_LB01), 127, 189, CAM_IMX682_SET_A_Full_1708p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_091_LTE_LB01), 190, 329, CAM_IMX682_SET_A_Full_1849p6_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_091_LTE_LB01), 330, 393, CAM_IMX682_SET_A_Full_1708p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_091_LTE_LB01), 394, 471, CAM_IMX682_SET_A_Full_1849p6_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_091_LTE_LB01), 472, 599, CAM_IMX682_SET_A_Full_1708p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_092_LTE_LB02), 600, 759, CAM_IMX682_SET_A_Full_1708p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_092_LTE_LB02), 760, 899, CAM_IMX682_SET_A_Full_1849p6_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_092_LTE_LB02), 900, 1176, CAM_IMX682_SET_A_Full_1708p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_092_LTE_LB02), 1177, 1199, CAM_IMX682_SET_A_Full_1849p6_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_093_LTE_LB03), 1200, 1388, CAM_IMX682_SET_A_Full_1708p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_093_LTE_LB03), 1389, 1528, CAM_IMX682_SET_A_Full_1849p6_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_093_LTE_LB03), 1529, 1795, CAM_IMX682_SET_A_Full_1708p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_093_LTE_LB03), 1796, 1935, CAM_IMX682_SET_A_Full_1849p6_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_093_LTE_LB03), 1936, 1949, CAM_IMX682_SET_A_Full_1708p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_094_LTE_LB04), 1950, 2076, CAM_IMX682_SET_A_Full_1849p6_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_094_LTE_LB04), 2077, 2139, CAM_IMX682_SET_A_Full_1708p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_094_LTE_LB04), 2140, 2279, CAM_IMX682_SET_A_Full_1849p6_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_094_LTE_LB04), 2280, 2343, CAM_IMX682_SET_A_Full_1708p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_094_LTE_LB04), 2344, 2399, CAM_IMX682_SET_A_Full_1849p6_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_095_LTE_LB05), 2400, 2590, CAM_IMX682_SET_A_Full_1708p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_095_LTE_LB05), 2591, 2649, CAM_IMX682_SET_A_Full_1849p6_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_097_LTE_LB07), 2750, 2984, CAM_IMX682_SET_A_Full_1708p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_097_LTE_LB07), 2985, 3065, CAM_IMX682_SET_A_Full_1849p6_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_097_LTE_LB07), 3066, 3332, CAM_IMX682_SET_A_Full_1708p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_097_LTE_LB07), 3333, 3449, CAM_IMX682_SET_A_Full_1849p6_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_098_LTE_LB08), 3450, 3502, CAM_IMX682_SET_A_Full_1708p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_098_LTE_LB08), 3503, 3627, CAM_IMX682_SET_A_Full_1849p6_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_098_LTE_LB08), 3628, 3799, CAM_IMX682_SET_A_Full_1708p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_102_LTE_LB12), 5010, 5113, CAM_IMX682_SET_A_Full_1849p6_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_102_LTE_LB12), 5114, 5179, CAM_IMX682_SET_A_Full_1708p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_103_LTE_LB13), 5180, 5279, CAM_IMX682_SET_A_Full_1708p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_104_LTE_LB14), 5280, 5360, CAM_IMX682_SET_A_Full_1708p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_104_LTE_LB14), 5361, 5379, CAM_IMX682_SET_A_Full_1849p6_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_107_LTE_LB17), 5730, 5783, CAM_IMX682_SET_A_Full_1849p6_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_107_LTE_LB17), 5784, 5849, CAM_IMX682_SET_A_Full_1708p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_108_LTE_LB18), 5850, 5863, CAM_IMX682_SET_A_Full_1849p6_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_108_LTE_LB18), 5864, 5999, CAM_IMX682_SET_A_Full_1708p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_109_LTE_LB19), 6000, 6130, CAM_IMX682_SET_A_Full_1708p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_109_LTE_LB19), 6131, 6149, CAM_IMX682_SET_A_Full_1849p6_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_110_LTE_LB20), 6150, 6307, CAM_IMX682_SET_A_Full_1708p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_110_LTE_LB20), 6308, 6447, CAM_IMX682_SET_A_Full_1849p6_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_110_LTE_LB20), 6448, 6449, CAM_IMX682_SET_A_Full_1708p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_111_LTE_LB21), 6450, 6599, CAM_IMX682_SET_A_Full_1849p6_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_115_LTE_LB25), 8040, 8199, CAM_IMX682_SET_A_Full_1708p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_115_LTE_LB25), 8200, 8339, CAM_IMX682_SET_A_Full_1849p6_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_115_LTE_LB25), 8340, 8616, CAM_IMX682_SET_A_Full_1708p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_115_LTE_LB25), 8617, 8689, CAM_IMX682_SET_A_Full_1849p6_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_116_LTE_LB26), 8690, 8713, CAM_IMX682_SET_A_Full_1849p6_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_116_LTE_LB26), 8714, 8980, CAM_IMX682_SET_A_Full_1708p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_116_LTE_LB26), 8981, 9039, CAM_IMX682_SET_A_Full_1849p6_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_118_LTE_LB28), 9210, 9290, CAM_IMX682_SET_A_Full_1708p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_118_LTE_LB28), 9291, 9430, CAM_IMX682_SET_A_Full_1849p6_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_118_LTE_LB28), 9431, 9659, CAM_IMX682_SET_A_Full_1708p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_119_LTE_LB29), 9660, 9743, CAM_IMX682_SET_A_Full_1708p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_119_LTE_LB29), 9744, 9769, CAM_IMX682_SET_A_Full_1849p6_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_120_LTE_LB30), 9770, 9869, CAM_IMX682_SET_A_Full_1849p6_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_122_LTE_LB32), 9920, 9989, CAM_IMX682_SET_A_Full_1708p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_122_LTE_LB32), 9990, 10116, CAM_IMX682_SET_A_Full_1849p6_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_122_LTE_LB32), 10117, 10281, CAM_IMX682_SET_A_Full_1708p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_122_LTE_LB32), 10282, 10359, CAM_IMX682_SET_A_Full_1849p6_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_124_LTE_LB34), 36200, 36349, CAM_IMX682_SET_A_Full_1708p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_128_LTE_LB38), 37750, 37751, CAM_IMX682_SET_A_Full_1849p6_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_128_LTE_LB38), 37752, 38060, CAM_IMX682_SET_A_Full_1708p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_128_LTE_LB38), 38061, 38158, CAM_IMX682_SET_A_Full_1849p6_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_128_LTE_LB38), 38159, 38249, CAM_IMX682_SET_A_Full_1708p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_129_LTE_LB39), 38250, 38502, CAM_IMX682_SET_A_Full_1708p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_129_LTE_LB39), 38503, 38649, CAM_IMX682_SET_A_Full_1849p6_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_130_LTE_LB40), 38650, 38805, CAM_IMX682_SET_A_Full_1708p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_130_LTE_LB40), 38806, 38910, CAM_IMX682_SET_A_Full_1849p6_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_130_LTE_LB40), 38911, 39075, CAM_IMX682_SET_A_Full_1708p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_130_LTE_LB40), 39076, 39317, CAM_IMX682_SET_A_Full_1849p6_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_130_LTE_LB40), 39318, 39584, CAM_IMX682_SET_A_Full_1708p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_130_LTE_LB40), 39585, 39649, CAM_IMX682_SET_A_Full_1849p6_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_131_LTE_LB41), 39650, 39853, CAM_IMX682_SET_A_Full_1708p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_131_LTE_LB41), 39854, 39985, CAM_IMX682_SET_A_Full_1849p6_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_131_LTE_LB41), 39986, 40277, CAM_IMX682_SET_A_Full_1708p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_131_LTE_LB41), 40278, 40391, CAM_IMX682_SET_A_Full_1849p6_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_131_LTE_LB41), 40392, 40700, CAM_IMX682_SET_A_Full_1708p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_131_LTE_LB41), 40701, 40798, CAM_IMX682_SET_A_Full_1849p6_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_131_LTE_LB41), 40799, 41124, CAM_IMX682_SET_A_Full_1708p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_131_LTE_LB41), 41125, 41205, CAM_IMX682_SET_A_Full_1849p6_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_131_LTE_LB41), 41206, 41472, CAM_IMX682_SET_A_Full_1708p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_131_LTE_LB41), 41473, 41589, CAM_IMX682_SET_A_Full_1849p6_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_132_LTE_LB42), 41590, 41696, CAM_IMX682_SET_A_Full_1708p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_132_LTE_LB42), 41697, 41836, CAM_IMX682_SET_A_Full_1849p6_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_132_LTE_LB42), 41837, 42102, CAM_IMX682_SET_A_Full_1708p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_132_LTE_LB42), 42103, 42221, CAM_IMX682_SET_A_Full_1849p6_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_132_LTE_LB42), 42222, 42509, CAM_IMX682_SET_A_Full_1708p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_132_LTE_LB42), 42510, 42649, CAM_IMX682_SET_A_Full_1849p6_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_132_LTE_LB42), 42650, 42916, CAM_IMX682_SET_A_Full_1708p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_132_LTE_LB42), 42917, 43056, CAM_IMX682_SET_A_Full_1849p6_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_132_LTE_LB42), 43057, 43327, CAM_IMX682_SET_A_Full_1708p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_132_LTE_LB42), 43328, 43463, CAM_IMX682_SET_A_Full_1849p6_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_132_LTE_LB42), 43464, 43589, CAM_IMX682_SET_A_Full_1708p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_138_LTE_LB48), 55240, 55477, CAM_IMX682_SET_A_Full_1708p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_138_LTE_LB48), 55478, 55613, CAM_IMX682_SET_A_Full_1849p6_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_138_LTE_LB48), 55614, 55901, CAM_IMX682_SET_A_Full_1708p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_138_LTE_LB48), 55902, 56122, CAM_IMX682_SET_A_Full_1849p6_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_138_LTE_LB48), 56123, 56324, CAM_IMX682_SET_A_Full_1708p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_138_LTE_LB48), 56325, 56427, CAM_IMX682_SET_A_Full_1849p6_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_138_LTE_LB48), 56428, 56739, CAM_IMX682_SET_A_Full_1708p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_156_LTE_LB66), 66436, 66562, CAM_IMX682_SET_A_Full_1849p6_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_156_LTE_LB66), 66563, 66625, CAM_IMX682_SET_A_Full_1708p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_156_LTE_LB66), 66626, 66765, CAM_IMX682_SET_A_Full_1849p6_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_156_LTE_LB66), 66766, 66829, CAM_IMX682_SET_A_Full_1708p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_156_LTE_LB66), 66830, 66907, CAM_IMX682_SET_A_Full_1849p6_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_156_LTE_LB66), 66908, 67236, CAM_IMX682_SET_A_Full_1708p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_156_LTE_LB66), 67237, 67335, CAM_IMX682_SET_A_Full_1849p6_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_161_LTE_LB71), 68586, 68753, CAM_IMX682_SET_A_Full_1708p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_161_LTE_LB71), 68754, 68935, CAM_IMX682_SET_A_Full_1849p6_MHZ },
{ CAM_RAT_BAND(CAM_RAT_4_TDSCDMA, CAM_BAND_051_TDSCDMA_TD1), 0, 0, CAM_IMX682_SET_A_Full_1708p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_4_TDSCDMA, CAM_BAND_052_TDSCDMA_TD2), 0, 0, CAM_IMX682_SET_A_Full_1708p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_4_TDSCDMA, CAM_BAND_053_TDSCDMA_TD3), 0, 0, CAM_IMX682_SET_A_Full_1849p6_MHZ },
{ CAM_RAT_BAND(CAM_RAT_4_TDSCDMA, CAM_BAND_054_TDSCDMA_TD4), 0, 0, CAM_IMX682_SET_A_Full_1849p6_MHZ },
{ CAM_RAT_BAND(CAM_RAT_4_TDSCDMA, CAM_BAND_055_TDSCDMA_TD5), 0, 0, CAM_IMX682_SET_A_Full_1849p6_MHZ },
{ CAM_RAT_BAND(CAM_RAT_4_TDSCDMA, CAM_BAND_056_TDSCDMA_TD6), 0, 0, CAM_IMX682_SET_A_Full_1849p6_MHZ },
{ CAM_RAT_BAND(CAM_RAT_5_CDMA, CAM_BAND_061_CDMA_BC0), 0, 0, CAM_IMX682_SET_A_Full_1849p6_MHZ },
{ CAM_RAT_BAND(CAM_RAT_5_CDMA, CAM_BAND_062_CDMA_BC1), 0, 0, CAM_IMX682_SET_A_Full_1849p6_MHZ },
{ CAM_RAT_BAND(CAM_RAT_5_CDMA, CAM_BAND_071_CDMA_BC10), 0, 0, CAM_IMX682_SET_A_Full_1849p6_MHZ },
};

static const struct cam_mipi_sensor_mode sensor_imx682_setfile_A_mipi_sensor_mode[] = {
    {
        sensor_imx682_setfile_A_channel,	ARRAY_SIZE(sensor_imx682_setfile_A_channel),
        sensor_imx682_setfile_A_mipi_setting,	ARRAY_SIZE(sensor_imx682_setfile_A_mipi_setting)
    },
};

enum {
    CAM_IMX682_SET_B_Quad_1580p8_MHZ = 0,
    CAM_IMX682_SET_B_Quad_1414p4_MHZ = 1,
};

struct cam_sensor_i2c_reg_array MIPI_B_1414p4_MHZ_REG_ARRAY[] = {
    {0x030F, 0xDD, 0x00, 0x00}
};

struct cam_sensor_i2c_reg_array MIPI_B_1580p8_MHZ_REG_ARRAY[] = {
    {0x030F, 0xF7, 0x00, 0x00}
};

static const struct cam_sensor_i2c_reg_setting sensor_imx682_setfile_B_1414p4_mhz[] = {
    { MIPI_B_1414p4_MHZ_REG_ARRAY, ARRAY_SIZE(MIPI_B_1414p4_MHZ_REG_ARRAY),
      CAMERA_SENSOR_I2C_TYPE_WORD, CAMERA_SENSOR_I2C_TYPE_BYTE, 0 }
};

static const struct cam_sensor_i2c_reg_setting sensor_imx682_setfile_B_1580p8_mhz[] = {
    { MIPI_B_1580p8_MHZ_REG_ARRAY, ARRAY_SIZE(MIPI_B_1580p8_MHZ_REG_ARRAY),
      CAMERA_SENSOR_I2C_TYPE_WORD, CAMERA_SENSOR_I2C_TYPE_BYTE, 0 }
};

static const struct cam_mipi_setting sensor_imx682_setfile_B_mipi_setting[] = {
    { "1580.8 Mhz",
      sensor_imx682_setfile_B_1580p8_mhz, ARRAY_SIZE(sensor_imx682_setfile_B_1580p8_mhz) },
    { "1414.4 Mhz",
      sensor_imx682_setfile_B_1414p4_mhz, ARRAY_SIZE(sensor_imx682_setfile_B_1414p4_mhz) },
};

static const struct cam_mipi_channel sensor_imx682_setfile_B_channel[] = {
{ CAM_RAT_BAND(CAM_RAT_1_GSM, CAM_BAND_001_GSM_GSM850), 0, 0, CAM_IMX682_SET_B_Quad_1414p4_MHZ },
{ CAM_RAT_BAND(CAM_RAT_1_GSM, CAM_BAND_002_GSM_EGSM900), 0, 0, CAM_IMX682_SET_B_Quad_1580p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_1_GSM, CAM_BAND_003_GSM_DCS1800), 0, 0, CAM_IMX682_SET_B_Quad_1580p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_1_GSM, CAM_BAND_004_GSM_PCS1900), 0, 0, CAM_IMX682_SET_B_Quad_1580p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_2_WCDMA, CAM_BAND_011_WCDMA_WB01), 10562, 10573, CAM_IMX682_SET_B_Quad_1414p4_MHZ },
{ CAM_RAT_BAND(CAM_RAT_2_WCDMA, CAM_BAND_011_WCDMA_WB01), 10574, 10691, CAM_IMX682_SET_B_Quad_1580p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_2_WCDMA, CAM_BAND_011_WCDMA_WB01), 10692, 10751, CAM_IMX682_SET_B_Quad_1414p4_MHZ },
{ CAM_RAT_BAND(CAM_RAT_2_WCDMA, CAM_BAND_011_WCDMA_WB01), 10752, 10832, CAM_IMX682_SET_B_Quad_1580p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_2_WCDMA, CAM_BAND_011_WCDMA_WB01), 10833, 10838, CAM_IMX682_SET_B_Quad_1414p4_MHZ },
{ CAM_RAT_BAND(CAM_RAT_2_WCDMA, CAM_BAND_012_WCDMA_WB02), 9662, 9776, CAM_IMX682_SET_B_Quad_1580p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_2_WCDMA, CAM_BAND_012_WCDMA_WB02), 9777, 9820, CAM_IMX682_SET_B_Quad_1414p4_MHZ },
{ CAM_RAT_BAND(CAM_RAT_2_WCDMA, CAM_BAND_012_WCDMA_WB02), 9821, 9844, CAM_IMX682_SET_B_Quad_1580p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_2_WCDMA, CAM_BAND_012_WCDMA_WB02), 9845, 9907, CAM_IMX682_SET_B_Quad_1414p4_MHZ },
{ CAM_RAT_BAND(CAM_RAT_2_WCDMA, CAM_BAND_012_WCDMA_WB02), 9908, 9938, CAM_IMX682_SET_B_Quad_1580p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_2_WCDMA, CAM_BAND_013_WCDMA_WB03), 1162, 1188, CAM_IMX682_SET_B_Quad_1414p4_MHZ },
{ CAM_RAT_BAND(CAM_RAT_2_WCDMA, CAM_BAND_013_WCDMA_WB03), 1189, 1311, CAM_IMX682_SET_B_Quad_1580p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_2_WCDMA, CAM_BAND_013_WCDMA_WB03), 1312, 1366, CAM_IMX682_SET_B_Quad_1414p4_MHZ },
{ CAM_RAT_BAND(CAM_RAT_2_WCDMA, CAM_BAND_013_WCDMA_WB03), 1367, 1499, CAM_IMX682_SET_B_Quad_1580p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_2_WCDMA, CAM_BAND_013_WCDMA_WB03), 1500, 1513, CAM_IMX682_SET_B_Quad_1414p4_MHZ },
{ CAM_RAT_BAND(CAM_RAT_2_WCDMA, CAM_BAND_014_WCDMA_WB04), 1537, 1548, CAM_IMX682_SET_B_Quad_1414p4_MHZ },
{ CAM_RAT_BAND(CAM_RAT_2_WCDMA, CAM_BAND_014_WCDMA_WB04), 1549, 1666, CAM_IMX682_SET_B_Quad_1580p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_2_WCDMA, CAM_BAND_014_WCDMA_WB04), 1667, 1726, CAM_IMX682_SET_B_Quad_1414p4_MHZ },
{ CAM_RAT_BAND(CAM_RAT_2_WCDMA, CAM_BAND_014_WCDMA_WB04), 1727, 1738, CAM_IMX682_SET_B_Quad_1580p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_2_WCDMA, CAM_BAND_015_WCDMA_WB05), 4357, 4458, CAM_IMX682_SET_B_Quad_1580p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_2_WCDMA, CAM_BAND_017_WCDMA_WB07), 2237, 2278, CAM_IMX682_SET_B_Quad_1580p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_2_WCDMA, CAM_BAND_017_WCDMA_WB07), 2279, 2333, CAM_IMX682_SET_B_Quad_1414p4_MHZ },
{ CAM_RAT_BAND(CAM_RAT_2_WCDMA, CAM_BAND_017_WCDMA_WB07), 2334, 2457, CAM_IMX682_SET_B_Quad_1580p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_2_WCDMA, CAM_BAND_017_WCDMA_WB07), 2458, 2521, CAM_IMX682_SET_B_Quad_1414p4_MHZ },
{ CAM_RAT_BAND(CAM_RAT_2_WCDMA, CAM_BAND_017_WCDMA_WB07), 2522, 2563, CAM_IMX682_SET_B_Quad_1580p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_2_WCDMA, CAM_BAND_018_WCDMA_WB08), 2937, 2969, CAM_IMX682_SET_B_Quad_1580p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_2_WCDMA, CAM_BAND_018_WCDMA_WB08), 2970, 3009, CAM_IMX682_SET_B_Quad_1414p4_MHZ },
{ CAM_RAT_BAND(CAM_RAT_2_WCDMA, CAM_BAND_018_WCDMA_WB08), 3010, 3088, CAM_IMX682_SET_B_Quad_1580p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_091_LTE_LB01), 0, 46, CAM_IMX682_SET_B_Quad_1414p4_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_091_LTE_LB01), 47, 283, CAM_IMX682_SET_B_Quad_1580p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_091_LTE_LB01), 284, 403, CAM_IMX682_SET_B_Quad_1414p4_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_091_LTE_LB01), 404, 565, CAM_IMX682_SET_B_Quad_1580p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_091_LTE_LB01), 566, 599, CAM_IMX682_SET_B_Quad_1414p4_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_092_LTE_LB02), 600, 852, CAM_IMX682_SET_B_Quad_1580p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_092_LTE_LB02), 853, 941, CAM_IMX682_SET_B_Quad_1414p4_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_092_LTE_LB02), 942, 989, CAM_IMX682_SET_B_Quad_1580p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_092_LTE_LB02), 990, 1114, CAM_IMX682_SET_B_Quad_1414p4_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_092_LTE_LB02), 1115, 1199, CAM_IMX682_SET_B_Quad_1580p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_093_LTE_LB03), 1200, 1276, CAM_IMX682_SET_B_Quad_1414p4_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_093_LTE_LB03), 1277, 1522, CAM_IMX682_SET_B_Quad_1580p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_093_LTE_LB03), 1523, 1632, CAM_IMX682_SET_B_Quad_1414p4_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_093_LTE_LB03), 1633, 1899, CAM_IMX682_SET_B_Quad_1580p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_093_LTE_LB03), 1900, 1949, CAM_IMX682_SET_B_Quad_1414p4_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_094_LTE_LB04), 1950, 1996, CAM_IMX682_SET_B_Quad_1414p4_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_094_LTE_LB04), 1997, 2233, CAM_IMX682_SET_B_Quad_1580p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_094_LTE_LB04), 2234, 2353, CAM_IMX682_SET_B_Quad_1414p4_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_094_LTE_LB04), 2354, 2399, CAM_IMX682_SET_B_Quad_1580p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_095_LTE_LB05), 2400, 2649, CAM_IMX682_SET_B_Quad_1580p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_097_LTE_LB07), 2750, 2857, CAM_IMX682_SET_B_Quad_1580p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_097_LTE_LB07), 2858, 2966, CAM_IMX682_SET_B_Quad_1414p4_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_097_LTE_LB07), 2967, 3214, CAM_IMX682_SET_B_Quad_1580p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_097_LTE_LB07), 3215, 3343, CAM_IMX682_SET_B_Quad_1414p4_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_097_LTE_LB07), 3344, 3449, CAM_IMX682_SET_B_Quad_1580p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_098_LTE_LB08), 3450, 3539, CAM_IMX682_SET_B_Quad_1580p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_098_LTE_LB08), 3540, 3619, CAM_IMX682_SET_B_Quad_1414p4_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_098_LTE_LB08), 3620, 3799, CAM_IMX682_SET_B_Quad_1580p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_102_LTE_LB12), 5010, 5179, CAM_IMX682_SET_B_Quad_1580p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_103_LTE_LB13), 5180, 5279, CAM_IMX682_SET_B_Quad_1414p4_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_104_LTE_LB14), 5280, 5297, CAM_IMX682_SET_B_Quad_1414p4_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_104_LTE_LB14), 5298, 5379, CAM_IMX682_SET_B_Quad_1580p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_107_LTE_LB17), 5730, 5849, CAM_IMX682_SET_B_Quad_1580p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_108_LTE_LB18), 5850, 5956, CAM_IMX682_SET_B_Quad_1414p4_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_108_LTE_LB18), 5957, 5999, CAM_IMX682_SET_B_Quad_1580p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_109_LTE_LB19), 6000, 6149, CAM_IMX682_SET_B_Quad_1580p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_110_LTE_LB20), 6150, 6213, CAM_IMX682_SET_B_Quad_1414p4_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_110_LTE_LB20), 6214, 6449, CAM_IMX682_SET_B_Quad_1580p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_111_LTE_LB21), 6450, 6476, CAM_IMX682_SET_B_Quad_1580p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_111_LTE_LB21), 6477, 6599, CAM_IMX682_SET_B_Quad_1414p4_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_115_LTE_LB25), 8040, 8292, CAM_IMX682_SET_B_Quad_1580p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_115_LTE_LB25), 8293, 8381, CAM_IMX682_SET_B_Quad_1414p4_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_115_LTE_LB25), 8382, 8429, CAM_IMX682_SET_B_Quad_1580p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_115_LTE_LB25), 8430, 8554, CAM_IMX682_SET_B_Quad_1414p4_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_115_LTE_LB25), 8555, 8648, CAM_IMX682_SET_B_Quad_1580p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_115_LTE_LB25), 8649, 8689, CAM_IMX682_SET_B_Quad_1414p4_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_116_LTE_LB26), 8690, 8806, CAM_IMX682_SET_B_Quad_1414p4_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_116_LTE_LB26), 8807, 9039, CAM_IMX682_SET_B_Quad_1580p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_118_LTE_LB28), 9210, 9227, CAM_IMX682_SET_B_Quad_1414p4_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_118_LTE_LB28), 9228, 9463, CAM_IMX682_SET_B_Quad_1580p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_118_LTE_LB28), 9464, 9603, CAM_IMX682_SET_B_Quad_1414p4_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_118_LTE_LB28), 9604, 9659, CAM_IMX682_SET_B_Quad_1580p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_119_LTE_LB29), 9660, 9711, CAM_IMX682_SET_B_Quad_1414p4_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_119_LTE_LB29), 9712, 9769, CAM_IMX682_SET_B_Quad_1580p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_120_LTE_LB30), 9770, 9869, CAM_IMX682_SET_B_Quad_1580p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_122_LTE_LB32), 9920, 10008, CAM_IMX682_SET_B_Quad_1580p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_122_LTE_LB32), 10009, 10148, CAM_IMX682_SET_B_Quad_1414p4_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_122_LTE_LB32), 10149, 10359, CAM_IMX682_SET_B_Quad_1580p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_124_LTE_LB34), 36200, 36349, CAM_IMX682_SET_B_Quad_1580p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_128_LTE_LB38), 37750, 37807, CAM_IMX682_SET_B_Quad_1414p4_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_128_LTE_LB38), 37808, 38000, CAM_IMX682_SET_B_Quad_1580p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_128_LTE_LB38), 38001, 38090, CAM_IMX682_SET_B_Quad_1414p4_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_128_LTE_LB38), 38091, 38249, CAM_IMX682_SET_B_Quad_1580p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_129_LTE_LB39), 38250, 38649, CAM_IMX682_SET_B_Quad_1580p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_130_LTE_LB40), 38650, 38936, CAM_IMX682_SET_B_Quad_1580p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_130_LTE_LB40), 38937, 39055, CAM_IMX682_SET_B_Quad_1414p4_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_130_LTE_LB40), 39056, 39292, CAM_IMX682_SET_B_Quad_1580p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_130_LTE_LB40), 39293, 39431, CAM_IMX682_SET_B_Quad_1414p4_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_130_LTE_LB40), 39432, 39649, CAM_IMX682_SET_B_Quad_1580p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_131_LTE_LB41), 39650, 39837, CAM_IMX682_SET_B_Quad_1580p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_131_LTE_LB41), 39838, 39927, CAM_IMX682_SET_B_Quad_1414p4_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_131_LTE_LB41), 39928, 40283, CAM_IMX682_SET_B_Quad_1580p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_131_LTE_LB41), 40284, 40447, CAM_IMX682_SET_B_Quad_1414p4_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_131_LTE_LB41), 40448, 40640, CAM_IMX682_SET_B_Quad_1580p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_131_LTE_LB41), 40641, 40730, CAM_IMX682_SET_B_Quad_1414p4_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_131_LTE_LB41), 40731, 40997, CAM_IMX682_SET_B_Quad_1580p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_131_LTE_LB41), 40998, 41106, CAM_IMX682_SET_B_Quad_1414p4_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_131_LTE_LB41), 41107, 41354, CAM_IMX682_SET_B_Quad_1580p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_131_LTE_LB41), 41355, 41483, CAM_IMX682_SET_B_Quad_1414p4_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_131_LTE_LB41), 41484, 41589, CAM_IMX682_SET_B_Quad_1580p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_132_LTE_LB42), 41590, 41770, CAM_IMX682_SET_B_Quad_1580p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_132_LTE_LB42), 41771, 41890, CAM_IMX682_SET_B_Quad_1414p4_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_132_LTE_LB42), 41891, 42147, CAM_IMX682_SET_B_Quad_1580p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_132_LTE_LB42), 42148, 42247, CAM_IMX682_SET_B_Quad_1414p4_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_132_LTE_LB42), 42248, 42523, CAM_IMX682_SET_B_Quad_1580p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_132_LTE_LB42), 42524, 42603, CAM_IMX682_SET_B_Quad_1414p4_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_132_LTE_LB42), 42604, 42960, CAM_IMX682_SET_B_Quad_1580p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_132_LTE_LB42), 42961, 43039, CAM_IMX682_SET_B_Quad_1414p4_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_132_LTE_LB42), 43040, 43088, CAM_IMX682_SET_B_Quad_1580p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_132_LTE_LB42), 43089, 43222, CAM_IMX682_SET_B_Quad_1414p4_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_132_LTE_LB42), 43223, 43316, CAM_IMX682_SET_B_Quad_1580p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_132_LTE_LB42), 43317, 43416, CAM_IMX682_SET_B_Quad_1414p4_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_132_LTE_LB42), 43417, 43589, CAM_IMX682_SET_B_Quad_1580p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_138_LTE_LB48), 55240, 55372, CAM_IMX682_SET_B_Quad_1414p4_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_138_LTE_LB48), 55373, 55466, CAM_IMX682_SET_B_Quad_1580p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_138_LTE_LB48), 55467, 55566, CAM_IMX682_SET_B_Quad_1414p4_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_138_LTE_LB48), 55567, 55823, CAM_IMX682_SET_B_Quad_1580p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_138_LTE_LB48), 55824, 55942, CAM_IMX682_SET_B_Quad_1414p4_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_138_LTE_LB48), 55943, 56179, CAM_IMX682_SET_B_Quad_1580p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_138_LTE_LB48), 56180, 56318, CAM_IMX682_SET_B_Quad_1414p4_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_138_LTE_LB48), 56319, 56555, CAM_IMX682_SET_B_Quad_1580p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_138_LTE_LB48), 56556, 56695, CAM_IMX682_SET_B_Quad_1414p4_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_138_LTE_LB48), 56696, 56739, CAM_IMX682_SET_B_Quad_1580p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_156_LTE_LB66), 66436, 66482, CAM_IMX682_SET_B_Quad_1414p4_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_156_LTE_LB66), 66483, 66719, CAM_IMX682_SET_B_Quad_1580p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_156_LTE_LB66), 66720, 66839, CAM_IMX682_SET_B_Quad_1414p4_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_156_LTE_LB66), 66840, 67001, CAM_IMX682_SET_B_Quad_1580p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_156_LTE_LB66), 67002, 67196, CAM_IMX682_SET_B_Quad_1414p4_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_156_LTE_LB66), 67197, 67335, CAM_IMX682_SET_B_Quad_1580p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_161_LTE_LB71), 68586, 68814, CAM_IMX682_SET_B_Quad_1580p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_161_LTE_LB71), 68815, 68935, CAM_IMX682_SET_B_Quad_1580p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_4_TDSCDMA, CAM_BAND_051_TDSCDMA_TD1), 0, 0, CAM_IMX682_SET_B_Quad_1414p4_MHZ },
{ CAM_RAT_BAND(CAM_RAT_4_TDSCDMA, CAM_BAND_052_TDSCDMA_TD2), 0, 0, CAM_IMX682_SET_B_Quad_1580p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_4_TDSCDMA, CAM_BAND_053_TDSCDMA_TD3), 0, 0, CAM_IMX682_SET_B_Quad_1580p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_4_TDSCDMA, CAM_BAND_054_TDSCDMA_TD4), 0, 0, CAM_IMX682_SET_B_Quad_1580p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_4_TDSCDMA, CAM_BAND_055_TDSCDMA_TD5), 0, 0, CAM_IMX682_SET_B_Quad_1414p4_MHZ },
{ CAM_RAT_BAND(CAM_RAT_4_TDSCDMA, CAM_BAND_056_TDSCDMA_TD6), 0, 0, CAM_IMX682_SET_B_Quad_1580p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_5_CDMA, CAM_BAND_061_CDMA_BC0), 0, 0, CAM_IMX682_SET_B_Quad_1414p4_MHZ },
{ CAM_RAT_BAND(CAM_RAT_5_CDMA, CAM_BAND_062_CDMA_BC1), 0, 0, CAM_IMX682_SET_B_Quad_1414p4_MHZ },
{ CAM_RAT_BAND(CAM_RAT_5_CDMA, CAM_BAND_071_CDMA_BC10), 0, 0, CAM_IMX682_SET_B_Quad_1580p8_MHZ },
};

static const struct cam_mipi_sensor_mode sensor_imx682_setfile_B_mipi_sensor_mode[] = {
    {
        sensor_imx682_setfile_B_channel,	ARRAY_SIZE(sensor_imx682_setfile_B_channel),
        sensor_imx682_setfile_B_mipi_setting,	ARRAY_SIZE(sensor_imx682_setfile_B_mipi_setting)
    },
};

enum {
    CAM_IMX682_SET_C_HiSpeed_1580p8_MHZ = 0,
    CAM_IMX682_SET_C_HiSpeed_1702p4_MHZ = 1,
};

struct cam_sensor_i2c_reg_array MIPI_C_1580p8_MHZ_REG_ARRAY[] = {
    {0x0341, 0x8E, 0x00, 0x00},
    {0x0307, 0x23, 0x00, 0x00},
    {0x030E, 0x00, 0x00, 0x00},
    {0x030F, 0xF7, 0x00, 0x00},
    {0x0202, 0x05, 0x00, 0x00},
    {0x0203, 0x5E, 0x00, 0x00}
};

struct cam_sensor_i2c_reg_array MIPI_C_1702p4_MHZ_REG_ARRAY[] = {
    {0x0341, 0x22, 0x00, 0x00},
    {0x0307, 0x0D, 0x00, 0x00},
    {0x030E, 0x01, 0x00, 0x00},
    {0x030F, 0x0A, 0x00, 0x00},
    {0x0202, 0x04, 0x00, 0x00},
    {0x0203, 0xF2, 0x00, 0x00}
};

static const struct cam_sensor_i2c_reg_setting sensor_imx682_setfile_C_1580p8_mhz[] = {
    { MIPI_C_1580p8_MHZ_REG_ARRAY, ARRAY_SIZE(MIPI_C_1580p8_MHZ_REG_ARRAY),
      CAMERA_SENSOR_I2C_TYPE_WORD, CAMERA_SENSOR_I2C_TYPE_BYTE, 0 }
};

static const struct cam_sensor_i2c_reg_setting sensor_imx682_setfile_C_1702p4_mhz[] = {
    { MIPI_C_1702p4_MHZ_REG_ARRAY, ARRAY_SIZE(MIPI_C_1702p4_MHZ_REG_ARRAY),
      CAMERA_SENSOR_I2C_TYPE_WORD, CAMERA_SENSOR_I2C_TYPE_BYTE, 0 }
};

static const struct cam_mipi_setting sensor_imx682_setfile_C_mipi_setting[] = {
    { "1580.8 Mhz",
      sensor_imx682_setfile_C_1580p8_mhz, ARRAY_SIZE(sensor_imx682_setfile_C_1580p8_mhz) },
    { "1702.4 Mhz",
      sensor_imx682_setfile_C_1702p4_mhz, ARRAY_SIZE(sensor_imx682_setfile_C_1702p4_mhz) },
};

static const struct cam_mipi_channel sensor_imx682_setfile_C_channel[] = {
{ CAM_RAT_BAND(CAM_RAT_1_GSM, CAM_BAND_001_GSM_GSM850), 0, 0, CAM_IMX682_SET_C_HiSpeed_1580p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_1_GSM, CAM_BAND_002_GSM_EGSM900), 0, 0, CAM_IMX682_SET_C_HiSpeed_1580p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_1_GSM, CAM_BAND_003_GSM_DCS1800), 0, 0, CAM_IMX682_SET_C_HiSpeed_1702p4_MHZ },
{ CAM_RAT_BAND(CAM_RAT_1_GSM, CAM_BAND_004_GSM_PCS1900), 0, 0, CAM_IMX682_SET_C_HiSpeed_1580p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_2_WCDMA, CAM_BAND_011_WCDMA_WB01), 10562, 10691, CAM_IMX682_SET_C_HiSpeed_1580p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_2_WCDMA, CAM_BAND_011_WCDMA_WB01), 10692, 10734, CAM_IMX682_SET_C_HiSpeed_1702p4_MHZ },
{ CAM_RAT_BAND(CAM_RAT_2_WCDMA, CAM_BAND_011_WCDMA_WB01), 10735, 10832, CAM_IMX682_SET_C_HiSpeed_1580p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_2_WCDMA, CAM_BAND_011_WCDMA_WB01), 10833, 10838, CAM_IMX682_SET_C_HiSpeed_1702p4_MHZ },
{ CAM_RAT_BAND(CAM_RAT_2_WCDMA, CAM_BAND_012_WCDMA_WB02), 9662, 9756, CAM_IMX682_SET_C_HiSpeed_1580p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_2_WCDMA, CAM_BAND_012_WCDMA_WB02), 9757, 9820, CAM_IMX682_SET_C_HiSpeed_1702p4_MHZ },
{ CAM_RAT_BAND(CAM_RAT_2_WCDMA, CAM_BAND_012_WCDMA_WB02), 9821, 9844, CAM_IMX682_SET_C_HiSpeed_1580p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_2_WCDMA, CAM_BAND_012_WCDMA_WB02), 9845, 9905, CAM_IMX682_SET_C_HiSpeed_1702p4_MHZ },
{ CAM_RAT_BAND(CAM_RAT_2_WCDMA, CAM_BAND_012_WCDMA_WB02), 9906, 9938, CAM_IMX682_SET_C_HiSpeed_1580p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_2_WCDMA, CAM_BAND_013_WCDMA_WB03), 1162, 1193, CAM_IMX682_SET_C_HiSpeed_1702p4_MHZ },
{ CAM_RAT_BAND(CAM_RAT_2_WCDMA, CAM_BAND_013_WCDMA_WB03), 1194, 1311, CAM_IMX682_SET_C_HiSpeed_1580p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_2_WCDMA, CAM_BAND_013_WCDMA_WB03), 1312, 1381, CAM_IMX682_SET_C_HiSpeed_1702p4_MHZ },
{ CAM_RAT_BAND(CAM_RAT_2_WCDMA, CAM_BAND_013_WCDMA_WB03), 1382, 1499, CAM_IMX682_SET_C_HiSpeed_1580p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_2_WCDMA, CAM_BAND_013_WCDMA_WB03), 1500, 1513, CAM_IMX682_SET_C_HiSpeed_1702p4_MHZ },
{ CAM_RAT_BAND(CAM_RAT_2_WCDMA, CAM_BAND_014_WCDMA_WB04), 1537, 1666, CAM_IMX682_SET_C_HiSpeed_1580p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_2_WCDMA, CAM_BAND_014_WCDMA_WB04), 1667, 1709, CAM_IMX682_SET_C_HiSpeed_1702p4_MHZ },
{ CAM_RAT_BAND(CAM_RAT_2_WCDMA, CAM_BAND_014_WCDMA_WB04), 1710, 1738, CAM_IMX682_SET_C_HiSpeed_1580p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_2_WCDMA, CAM_BAND_015_WCDMA_WB05), 4357, 4363, CAM_IMX682_SET_C_HiSpeed_1702p4_MHZ },
{ CAM_RAT_BAND(CAM_RAT_2_WCDMA, CAM_BAND_015_WCDMA_WB05), 4364, 4458, CAM_IMX682_SET_C_HiSpeed_1580p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_2_WCDMA, CAM_BAND_017_WCDMA_WB07), 2237, 2298, CAM_IMX682_SET_C_HiSpeed_1580p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_2_WCDMA, CAM_BAND_017_WCDMA_WB07), 2299, 2451, CAM_IMX682_SET_C_HiSpeed_1580p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_2_WCDMA, CAM_BAND_017_WCDMA_WB07), 2452, 2493, CAM_IMX682_SET_C_HiSpeed_1702p4_MHZ },
{ CAM_RAT_BAND(CAM_RAT_2_WCDMA, CAM_BAND_017_WCDMA_WB07), 2494, 2563, CAM_IMX682_SET_C_HiSpeed_1580p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_2_WCDMA, CAM_BAND_018_WCDMA_WB08), 2937, 2983, CAM_IMX682_SET_C_HiSpeed_1580p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_2_WCDMA, CAM_BAND_018_WCDMA_WB08), 2984, 3039, CAM_IMX682_SET_C_HiSpeed_1702p4_MHZ },
{ CAM_RAT_BAND(CAM_RAT_2_WCDMA, CAM_BAND_018_WCDMA_WB08), 3040, 3088, CAM_IMX682_SET_C_HiSpeed_1580p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_091_LTE_LB01), 0, 283, CAM_IMX682_SET_C_HiSpeed_1580p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_091_LTE_LB01), 284, 368, CAM_IMX682_SET_C_HiSpeed_1702p4_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_091_LTE_LB01), 369, 565, CAM_IMX682_SET_C_HiSpeed_1580p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_091_LTE_LB01), 566, 599, CAM_IMX682_SET_C_HiSpeed_1702p4_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_092_LTE_LB02), 600, 813, CAM_IMX682_SET_C_HiSpeed_1580p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_092_LTE_LB02), 814, 941, CAM_IMX682_SET_C_HiSpeed_1702p4_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_092_LTE_LB02), 942, 989, CAM_IMX682_SET_C_HiSpeed_1580p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_092_LTE_LB02), 990, 1110, CAM_IMX682_SET_C_HiSpeed_1702p4_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_092_LTE_LB02), 1111, 1199, CAM_IMX682_SET_C_HiSpeed_1580p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_093_LTE_LB03), 1200, 1286, CAM_IMX682_SET_C_HiSpeed_1702p4_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_093_LTE_LB03), 1287, 1522, CAM_IMX682_SET_C_HiSpeed_1580p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_093_LTE_LB03), 1523, 1662, CAM_IMX682_SET_C_HiSpeed_1702p4_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_093_LTE_LB03), 1663, 1899, CAM_IMX682_SET_C_HiSpeed_1580p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_093_LTE_LB03), 1900, 1949, CAM_IMX682_SET_C_HiSpeed_1702p4_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_094_LTE_LB04), 1950, 2233, CAM_IMX682_SET_C_HiSpeed_1580p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_094_LTE_LB04), 2234, 2318, CAM_IMX682_SET_C_HiSpeed_1702p4_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_094_LTE_LB04), 2319, 2399, CAM_IMX682_SET_C_HiSpeed_1580p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_095_LTE_LB05), 2400, 2436, CAM_IMX682_SET_C_HiSpeed_1702p4_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_095_LTE_LB05), 2437, 2649, CAM_IMX682_SET_C_HiSpeed_1580p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_097_LTE_LB07), 2750, 2896, CAM_IMX682_SET_C_HiSpeed_1580p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_097_LTE_LB07), 2897, 3203, CAM_IMX682_SET_C_HiSpeed_1580p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_097_LTE_LB07), 3204, 3287, CAM_IMX682_SET_C_HiSpeed_1702p4_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_097_LTE_LB07), 3288, 3449, CAM_IMX682_SET_C_HiSpeed_1580p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_098_LTE_LB08), 3450, 3566, CAM_IMX682_SET_C_HiSpeed_1580p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_098_LTE_LB08), 3567, 3679, CAM_IMX682_SET_C_HiSpeed_1702p4_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_098_LTE_LB08), 3680, 3799, CAM_IMX682_SET_C_HiSpeed_1580p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_102_LTE_LB12), 5010, 5177, CAM_IMX682_SET_C_HiSpeed_1580p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_102_LTE_LB12), 5178, 5179, CAM_IMX682_SET_C_HiSpeed_1702p4_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_103_LTE_LB13), 5180, 5279, CAM_IMX682_SET_C_HiSpeed_1702p4_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_104_LTE_LB14), 5280, 5297, CAM_IMX682_SET_C_HiSpeed_1702p4_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_104_LTE_LB14), 5298, 5379, CAM_IMX682_SET_C_HiSpeed_1580p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_107_LTE_LB17), 5730, 5847, CAM_IMX682_SET_C_HiSpeed_1580p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_107_LTE_LB17), 5848, 5849, CAM_IMX682_SET_C_HiSpeed_1702p4_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_108_LTE_LB18), 5850, 5976, CAM_IMX682_SET_C_HiSpeed_1702p4_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_108_LTE_LB18), 5977, 5999, CAM_IMX682_SET_C_HiSpeed_1580p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_109_LTE_LB19), 6000, 6149, CAM_IMX682_SET_C_HiSpeed_1580p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_110_LTE_LB20), 6150, 6213, CAM_IMX682_SET_C_HiSpeed_1702p4_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_110_LTE_LB20), 6214, 6449, CAM_IMX682_SET_C_HiSpeed_1580p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_111_LTE_LB21), 6450, 6517, CAM_IMX682_SET_C_HiSpeed_1580p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_111_LTE_LB21), 6518, 6599, CAM_IMX682_SET_C_HiSpeed_1702p4_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_115_LTE_LB25), 8040, 8253, CAM_IMX682_SET_C_HiSpeed_1580p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_115_LTE_LB25), 8254, 8381, CAM_IMX682_SET_C_HiSpeed_1702p4_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_115_LTE_LB25), 8382, 8429, CAM_IMX682_SET_C_HiSpeed_1580p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_115_LTE_LB25), 8430, 8550, CAM_IMX682_SET_C_HiSpeed_1702p4_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_115_LTE_LB25), 8551, 8645, CAM_IMX682_SET_C_HiSpeed_1580p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_115_LTE_LB25), 8646, 8689, CAM_IMX682_SET_C_HiSpeed_1702p4_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_116_LTE_LB26), 8690, 8826, CAM_IMX682_SET_C_HiSpeed_1702p4_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_116_LTE_LB26), 8827, 9039, CAM_IMX682_SET_C_HiSpeed_1580p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_118_LTE_LB28), 9210, 9227, CAM_IMX682_SET_C_HiSpeed_1702p4_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_118_LTE_LB28), 9228, 9463, CAM_IMX682_SET_C_HiSpeed_1580p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_118_LTE_LB28), 9464, 9603, CAM_IMX682_SET_C_HiSpeed_1702p4_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_118_LTE_LB28), 9604, 9659, CAM_IMX682_SET_C_HiSpeed_1580p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_119_LTE_LB29), 9660, 9711, CAM_IMX682_SET_C_HiSpeed_1702p4_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_119_LTE_LB29), 9712, 9769, CAM_IMX682_SET_C_HiSpeed_1580p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_120_LTE_LB30), 9770, 9869, CAM_IMX682_SET_C_HiSpeed_1580p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_122_LTE_LB32), 9920, 10035, CAM_IMX682_SET_C_HiSpeed_1580p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_122_LTE_LB32), 10036, 10148, CAM_IMX682_SET_C_HiSpeed_1702p4_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_122_LTE_LB32), 10149, 10359, CAM_IMX682_SET_C_HiSpeed_1580p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_124_LTE_LB34), 36200, 36349, CAM_IMX682_SET_C_HiSpeed_1580p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_128_LTE_LB38), 37750, 37807, CAM_IMX682_SET_C_HiSpeed_1702p4_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_128_LTE_LB38), 37808, 38006, CAM_IMX682_SET_C_HiSpeed_1580p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_128_LTE_LB38), 38007, 38090, CAM_IMX682_SET_C_HiSpeed_1702p4_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_128_LTE_LB38), 38091, 38249, CAM_IMX682_SET_C_HiSpeed_1580p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_129_LTE_LB39), 38250, 38339, CAM_IMX682_SET_C_HiSpeed_1702p4_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_129_LTE_LB39), 38340, 38649, CAM_IMX682_SET_C_HiSpeed_1580p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_130_LTE_LB40), 38650, 38679, CAM_IMX682_SET_C_HiSpeed_1702p4_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_130_LTE_LB40), 38680, 38915, CAM_IMX682_SET_C_HiSpeed_1580p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_130_LTE_LB40), 38916, 39021, CAM_IMX682_SET_C_HiSpeed_1702p4_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_130_LTE_LB40), 39022, 39291, CAM_IMX682_SET_C_HiSpeed_1580p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_130_LTE_LB40), 39292, 39431, CAM_IMX682_SET_C_HiSpeed_1702p4_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_130_LTE_LB40), 39432, 39649, CAM_IMX682_SET_C_HiSpeed_1580p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_131_LTE_LB41), 39650, 39864, CAM_IMX682_SET_C_HiSpeed_1580p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_131_LTE_LB41), 39865, 39977, CAM_IMX682_SET_C_HiSpeed_1702p4_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_131_LTE_LB41), 39978, 40254, CAM_IMX682_SET_C_HiSpeed_1580p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_131_LTE_LB41), 40255, 40447, CAM_IMX682_SET_C_HiSpeed_1702p4_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_131_LTE_LB41), 40448, 40646, CAM_IMX682_SET_C_HiSpeed_1580p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_131_LTE_LB41), 40647, 40730, CAM_IMX682_SET_C_HiSpeed_1702p4_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_131_LTE_LB41), 40731, 41036, CAM_IMX682_SET_C_HiSpeed_1580p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_131_LTE_LB41), 41037, 41343, CAM_IMX682_SET_C_HiSpeed_1580p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_131_LTE_LB41), 41344, 41427, CAM_IMX682_SET_C_HiSpeed_1702p4_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_131_LTE_LB41), 41428, 41589, CAM_IMX682_SET_C_HiSpeed_1580p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_132_LTE_LB42), 41590, 41770, CAM_IMX682_SET_C_HiSpeed_1580p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_132_LTE_LB42), 41771, 41910, CAM_IMX682_SET_C_HiSpeed_1702p4_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_132_LTE_LB42), 41911, 42147, CAM_IMX682_SET_C_HiSpeed_1580p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_132_LTE_LB42), 42148, 42287, CAM_IMX682_SET_C_HiSpeed_1702p4_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_132_LTE_LB42), 42288, 42523, CAM_IMX682_SET_C_HiSpeed_1580p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_132_LTE_LB42), 42524, 42663, CAM_IMX682_SET_C_HiSpeed_1702p4_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_132_LTE_LB42), 42664, 42912, CAM_IMX682_SET_C_HiSpeed_1580p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_132_LTE_LB42), 42913, 43039, CAM_IMX682_SET_C_HiSpeed_1702p4_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_132_LTE_LB42), 43040, 43088, CAM_IMX682_SET_C_HiSpeed_1580p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_132_LTE_LB42), 43089, 43209, CAM_IMX682_SET_C_HiSpeed_1702p4_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_132_LTE_LB42), 43210, 43303, CAM_IMX682_SET_C_HiSpeed_1580p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_132_LTE_LB42), 43304, 43416, CAM_IMX682_SET_C_HiSpeed_1702p4_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_132_LTE_LB42), 43417, 43589, CAM_IMX682_SET_C_HiSpeed_1580p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_138_LTE_LB48), 55240, 55359, CAM_IMX682_SET_C_HiSpeed_1702p4_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_138_LTE_LB48), 55360, 55453, CAM_IMX682_SET_C_HiSpeed_1580p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_138_LTE_LB48), 55454, 55566, CAM_IMX682_SET_C_HiSpeed_1702p4_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_138_LTE_LB48), 55567, 55872, CAM_IMX682_SET_C_HiSpeed_1580p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_138_LTE_LB48), 55873, 56234, CAM_IMX682_SET_C_HiSpeed_1580p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_138_LTE_LB48), 56235, 56318, CAM_IMX682_SET_C_HiSpeed_1702p4_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_138_LTE_LB48), 56319, 56625, CAM_IMX682_SET_C_HiSpeed_1580p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_138_LTE_LB48), 56626, 56739, CAM_IMX682_SET_C_HiSpeed_1580p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_156_LTE_LB66), 66436, 66719, CAM_IMX682_SET_C_HiSpeed_1580p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_156_LTE_LB66), 66720, 66804, CAM_IMX682_SET_C_HiSpeed_1702p4_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_156_LTE_LB66), 66805, 67001, CAM_IMX682_SET_C_HiSpeed_1580p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_156_LTE_LB66), 67002, 67195, CAM_IMX682_SET_C_HiSpeed_1702p4_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_156_LTE_LB66), 67196, 67335, CAM_IMX682_SET_C_HiSpeed_1580p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_161_LTE_LB71), 68586, 68814, CAM_IMX682_SET_C_HiSpeed_1580p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_161_LTE_LB71), 68815, 68935, CAM_IMX682_SET_C_HiSpeed_1580p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_4_TDSCDMA, CAM_BAND_051_TDSCDMA_TD1), 0, 0, CAM_IMX682_SET_C_HiSpeed_1580p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_4_TDSCDMA, CAM_BAND_052_TDSCDMA_TD2), 0, 0, CAM_IMX682_SET_C_HiSpeed_1580p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_4_TDSCDMA, CAM_BAND_053_TDSCDMA_TD3), 0, 0, CAM_IMX682_SET_C_HiSpeed_1702p4_MHZ },
{ CAM_RAT_BAND(CAM_RAT_4_TDSCDMA, CAM_BAND_054_TDSCDMA_TD4), 0, 0, CAM_IMX682_SET_C_HiSpeed_1702p4_MHZ },
{ CAM_RAT_BAND(CAM_RAT_4_TDSCDMA, CAM_BAND_055_TDSCDMA_TD5), 0, 0, CAM_IMX682_SET_C_HiSpeed_1580p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_4_TDSCDMA, CAM_BAND_056_TDSCDMA_TD6), 0, 0, CAM_IMX682_SET_C_HiSpeed_1580p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_5_CDMA, CAM_BAND_061_CDMA_BC0), 0, 0, CAM_IMX682_SET_C_HiSpeed_1580p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_5_CDMA, CAM_BAND_062_CDMA_BC1), 0, 0, CAM_IMX682_SET_C_HiSpeed_1580p8_MHZ },
{ CAM_RAT_BAND(CAM_RAT_5_CDMA, CAM_BAND_071_CDMA_BC10), 0, 0, CAM_IMX682_SET_C_HiSpeed_1580p8_MHZ },
};

static const struct cam_mipi_sensor_mode sensor_imx682_setfile_C_mipi_sensor_mode[] = {
    {
        sensor_imx682_setfile_C_channel,	ARRAY_SIZE(sensor_imx682_setfile_C_channel),
        sensor_imx682_setfile_C_mipi_setting,	ARRAY_SIZE(sensor_imx682_setfile_C_mipi_setting)
    },
};
#endif /* _CAM_SENSOR_ADAPTIVE_MIPI_IMX682_H_ */
