/* Copyright (c) 2017, The Linux Foundation. All rights reserved.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License version 2 and
 * only version 2 as published by the Free Software Foundation.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 */

#ifndef _CAM_SENSOR_ADAPTIVE_MIPI_S5KJN1_H_
#define _CAM_SENSOR_ADAPTIVE_MIPI_S5KJN1_H_

#include "cam_sensor_dev.h"

/*
SET A : Full (64Mp 15FPS)
SET B : Binning (16MP 30FPS)
SET C : Fast AE, HFR (120fps, 240fps)
*/

enum {
    CAM_JN1_SET_A_all_723p2_MHZ = 0,
    CAM_JN1_SET_A_all_774p4_MHZ = 1,
    CAM_JN1_SET_A_all_793p6_MHZ = 2,
};

struct cam_sensor_i2c_reg_array MIPI_A_723p2_MHZ_REG_ARRAY[] = {
    {0x0310, 0x0071, 0x00, 0x00},
};

struct cam_sensor_i2c_reg_array MIPI_A_774p4_MHZ_REG_ARRAY[] = {
    {0x0310, 0x0079, 0x00, 0x00},
};

struct cam_sensor_i2c_reg_array MIPI_A_793p6_MHZ_REG_ARRAY[] = {
    {0x0310, 0x007C, 0x00, 0x00},
};

static const struct cam_sensor_i2c_reg_setting sensor_s5kjn1_setfile_A_723p2_mhz[] = {
    { MIPI_A_723p2_MHZ_REG_ARRAY, ARRAY_SIZE(MIPI_A_723p2_MHZ_REG_ARRAY),
      CAMERA_SENSOR_I2C_TYPE_WORD, CAMERA_SENSOR_I2C_TYPE_WORD, 0 }
};

static const struct cam_sensor_i2c_reg_setting sensor_s5kjn1_setfile_A_774p4_mhz[] = {
    { MIPI_A_774p4_MHZ_REG_ARRAY, ARRAY_SIZE(MIPI_A_774p4_MHZ_REG_ARRAY),
      CAMERA_SENSOR_I2C_TYPE_WORD, CAMERA_SENSOR_I2C_TYPE_WORD, 0 }
};

static const struct cam_sensor_i2c_reg_setting sensor_s5kjn1_setfile_A_793p6_mhz[] = {
    { MIPI_A_793p6_MHZ_REG_ARRAY, ARRAY_SIZE(MIPI_A_793p6_MHZ_REG_ARRAY),
      CAMERA_SENSOR_I2C_TYPE_WORD, CAMERA_SENSOR_I2C_TYPE_WORD, 0 }
};

static const struct cam_mipi_setting sensor_s5kjn1_setfile_A_mipi_setting[] = {
    { "723.2 Mhz",
      sensor_s5kjn1_setfile_A_723p2_mhz, ARRAY_SIZE(sensor_s5kjn1_setfile_A_723p2_mhz) },
    { "774.4 Mhz",
      sensor_s5kjn1_setfile_A_774p4_mhz, ARRAY_SIZE(sensor_s5kjn1_setfile_A_774p4_mhz) },
    { "793.6 Mhz",
      sensor_s5kjn1_setfile_A_793p6_mhz, ARRAY_SIZE(sensor_s5kjn1_setfile_A_793p6_mhz) },
};

static const struct cam_mipi_channel sensor_s5kjn1_setfile_A_channel[] = {
{ CAM_RAT_BAND(CAM_RAT_1_GSM, CAM_BAND_001_GSM_GSM850), 0, 0, CAM_JN1_SET_A_all_723p2_MHZ },
{ CAM_RAT_BAND(CAM_RAT_1_GSM, CAM_BAND_002_GSM_EGSM900), 0, 0, CAM_JN1_SET_A_all_793p6_MHZ },
{ CAM_RAT_BAND(CAM_RAT_1_GSM, CAM_BAND_003_GSM_DCS1800), 0, 0, CAM_JN1_SET_A_all_774p4_MHZ },
{ CAM_RAT_BAND(CAM_RAT_1_GSM, CAM_BAND_004_GSM_PCS1900), 0, 0, CAM_JN1_SET_A_all_723p2_MHZ },
{ CAM_RAT_BAND(CAM_RAT_2_WCDMA, CAM_BAND_011_WCDMA_WB01), 10562, 10629, CAM_JN1_SET_A_all_723p2_MHZ },
{ CAM_RAT_BAND(CAM_RAT_2_WCDMA, CAM_BAND_011_WCDMA_WB01), 10630, 10681, CAM_JN1_SET_A_all_793p6_MHZ },
{ CAM_RAT_BAND(CAM_RAT_2_WCDMA, CAM_BAND_011_WCDMA_WB01), 10682, 10704, CAM_JN1_SET_A_all_774p4_MHZ },
{ CAM_RAT_BAND(CAM_RAT_2_WCDMA, CAM_BAND_011_WCDMA_WB01), 10705, 10810, CAM_JN1_SET_A_all_723p2_MHZ },
{ CAM_RAT_BAND(CAM_RAT_2_WCDMA, CAM_BAND_011_WCDMA_WB01), 10811, 10838, CAM_JN1_SET_A_all_793p6_MHZ },
{ CAM_RAT_BAND(CAM_RAT_2_WCDMA, CAM_BAND_012_WCDMA_WB02), 9662, 9725, CAM_JN1_SET_A_all_723p2_MHZ },
{ CAM_RAT_BAND(CAM_RAT_2_WCDMA, CAM_BAND_012_WCDMA_WB02), 9726, 9800, CAM_JN1_SET_A_all_774p4_MHZ },
{ CAM_RAT_BAND(CAM_RAT_2_WCDMA, CAM_BAND_012_WCDMA_WB02), 9801, 9909, CAM_JN1_SET_A_all_723p2_MHZ },
{ CAM_RAT_BAND(CAM_RAT_2_WCDMA, CAM_BAND_012_WCDMA_WB02), 9910, 9938, CAM_JN1_SET_A_all_774p4_MHZ },
{ CAM_RAT_BAND(CAM_RAT_2_WCDMA, CAM_BAND_013_WCDMA_WB03), 1162, 1186, CAM_JN1_SET_A_all_774p4_MHZ },
{ CAM_RAT_BAND(CAM_RAT_2_WCDMA, CAM_BAND_013_WCDMA_WB03), 1187, 1202, CAM_JN1_SET_A_all_793p6_MHZ },
{ CAM_RAT_BAND(CAM_RAT_2_WCDMA, CAM_BAND_013_WCDMA_WB03), 1203, 1308, CAM_JN1_SET_A_all_723p2_MHZ },
{ CAM_RAT_BAND(CAM_RAT_2_WCDMA, CAM_BAND_013_WCDMA_WB03), 1309, 1380, CAM_JN1_SET_A_all_774p4_MHZ },
{ CAM_RAT_BAND(CAM_RAT_2_WCDMA, CAM_BAND_013_WCDMA_WB03), 1381, 1383, CAM_JN1_SET_A_all_793p6_MHZ },
{ CAM_RAT_BAND(CAM_RAT_2_WCDMA, CAM_BAND_013_WCDMA_WB03), 1384, 1489, CAM_JN1_SET_A_all_723p2_MHZ },
{ CAM_RAT_BAND(CAM_RAT_2_WCDMA, CAM_BAND_013_WCDMA_WB03), 1490, 1513, CAM_JN1_SET_A_all_774p4_MHZ },
{ CAM_RAT_BAND(CAM_RAT_2_WCDMA, CAM_BAND_014_WCDMA_WB04), 1537, 1604, CAM_JN1_SET_A_all_723p2_MHZ },
{ CAM_RAT_BAND(CAM_RAT_2_WCDMA, CAM_BAND_014_WCDMA_WB04), 1605, 1656, CAM_JN1_SET_A_all_793p6_MHZ },
{ CAM_RAT_BAND(CAM_RAT_2_WCDMA, CAM_BAND_014_WCDMA_WB04), 1657, 1679, CAM_JN1_SET_A_all_774p4_MHZ },
{ CAM_RAT_BAND(CAM_RAT_2_WCDMA, CAM_BAND_014_WCDMA_WB04), 1680, 1738, CAM_JN1_SET_A_all_723p2_MHZ },
{ CAM_RAT_BAND(CAM_RAT_2_WCDMA, CAM_BAND_015_WCDMA_WB05), 4357, 4376, CAM_JN1_SET_A_all_774p4_MHZ },
{ CAM_RAT_BAND(CAM_RAT_2_WCDMA, CAM_BAND_015_WCDMA_WB05), 4377, 4458, CAM_JN1_SET_A_all_723p2_MHZ },
{ CAM_RAT_BAND(CAM_RAT_2_WCDMA, CAM_BAND_016_WCDMA_WB06), 4387, 4413, CAM_JN1_SET_A_all_723p2_MHZ },
{ CAM_RAT_BAND(CAM_RAT_2_WCDMA, CAM_BAND_017_WCDMA_WB07), 2237, 2285, CAM_JN1_SET_A_all_723p2_MHZ },
{ CAM_RAT_BAND(CAM_RAT_2_WCDMA, CAM_BAND_017_WCDMA_WB07), 2286, 2327, CAM_JN1_SET_A_all_793p6_MHZ },
{ CAM_RAT_BAND(CAM_RAT_2_WCDMA, CAM_BAND_017_WCDMA_WB07), 2328, 2360, CAM_JN1_SET_A_all_774p4_MHZ },
{ CAM_RAT_BAND(CAM_RAT_2_WCDMA, CAM_BAND_017_WCDMA_WB07), 2361, 2466, CAM_JN1_SET_A_all_723p2_MHZ },
{ CAM_RAT_BAND(CAM_RAT_2_WCDMA, CAM_BAND_017_WCDMA_WB07), 2467, 2520, CAM_JN1_SET_A_all_793p6_MHZ },
{ CAM_RAT_BAND(CAM_RAT_2_WCDMA, CAM_BAND_017_WCDMA_WB07), 2521, 2541, CAM_JN1_SET_A_all_774p4_MHZ },
{ CAM_RAT_BAND(CAM_RAT_2_WCDMA, CAM_BAND_017_WCDMA_WB07), 2542, 2563, CAM_JN1_SET_A_all_723p2_MHZ },
{ CAM_RAT_BAND(CAM_RAT_2_WCDMA, CAM_BAND_018_WCDMA_WB08), 2937, 2963, CAM_JN1_SET_A_all_723p2_MHZ },
{ CAM_RAT_BAND(CAM_RAT_2_WCDMA, CAM_BAND_018_WCDMA_WB08), 2964, 2983, CAM_JN1_SET_A_all_793p6_MHZ },
{ CAM_RAT_BAND(CAM_RAT_2_WCDMA, CAM_BAND_018_WCDMA_WB08), 2984, 3038, CAM_JN1_SET_A_all_774p4_MHZ },
{ CAM_RAT_BAND(CAM_RAT_2_WCDMA, CAM_BAND_018_WCDMA_WB08), 3039, 3088, CAM_JN1_SET_A_all_723p2_MHZ },
{ CAM_RAT_BAND(CAM_RAT_2_WCDMA, CAM_BAND_029_WCDMA_WB19), 712, 763, CAM_JN1_SET_A_all_723p2_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_091_LTE_LB01), 0, 159, CAM_JN1_SET_A_all_723p2_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_091_LTE_LB01), 160, 261, CAM_JN1_SET_A_all_793p6_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_091_LTE_LB01), 262, 309, CAM_JN1_SET_A_all_774p4_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_091_LTE_LB01), 310, 520, CAM_JN1_SET_A_all_723p2_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_091_LTE_LB01), 521, 599, CAM_JN1_SET_A_all_793p6_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_092_LTE_LB02), 600, 751, CAM_JN1_SET_A_all_723p2_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_092_LTE_LB02), 752, 901, CAM_JN1_SET_A_all_774p4_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_092_LTE_LB02), 902, 1117, CAM_JN1_SET_A_all_723p2_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_092_LTE_LB02), 1118, 1199, CAM_JN1_SET_A_all_774p4_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_093_LTE_LB03), 1200, 1273, CAM_JN1_SET_A_all_774p4_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_093_LTE_LB03), 1274, 1304, CAM_JN1_SET_A_all_793p6_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_093_LTE_LB03), 1305, 1516, CAM_JN1_SET_A_all_723p2_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_093_LTE_LB03), 1517, 1660, CAM_JN1_SET_A_all_774p4_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_093_LTE_LB03), 1661, 1666, CAM_JN1_SET_A_all_793p6_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_093_LTE_LB03), 1667, 1878, CAM_JN1_SET_A_all_723p2_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_093_LTE_LB03), 1879, 1949, CAM_JN1_SET_A_all_774p4_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_094_LTE_LB04), 1950, 2109, CAM_JN1_SET_A_all_723p2_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_094_LTE_LB04), 2110, 2211, CAM_JN1_SET_A_all_793p6_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_094_LTE_LB04), 2212, 2259, CAM_JN1_SET_A_all_774p4_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_094_LTE_LB04), 2260, 2399, CAM_JN1_SET_A_all_723p2_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_095_LTE_LB05), 2400, 2463, CAM_JN1_SET_A_all_774p4_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_095_LTE_LB05), 2464, 2649, CAM_JN1_SET_A_all_723p2_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_097_LTE_LB07), 2750, 2871, CAM_JN1_SET_A_all_723p2_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_097_LTE_LB07), 2872, 2954, CAM_JN1_SET_A_all_793p6_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_097_LTE_LB07), 2955, 3021, CAM_JN1_SET_A_all_774p4_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_097_LTE_LB07), 3022, 3233, CAM_JN1_SET_A_all_723p2_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_097_LTE_LB07), 3234, 3341, CAM_JN1_SET_A_all_793p6_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_097_LTE_LB07), 3342, 3383, CAM_JN1_SET_A_all_774p4_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_097_LTE_LB07), 3384, 3449, CAM_JN1_SET_A_all_723p2_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_098_LTE_LB08), 3450, 3526, CAM_JN1_SET_A_all_723p2_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_098_LTE_LB08), 3527, 3567, CAM_JN1_SET_A_all_793p6_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_098_LTE_LB08), 3568, 3676, CAM_JN1_SET_A_all_774p4_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_098_LTE_LB08), 3677, 3799, CAM_JN1_SET_A_all_723p2_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_102_LTE_LB12), 5010, 5026, CAM_JN1_SET_A_all_793p6_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_102_LTE_LB12), 5027, 5179, CAM_JN1_SET_A_all_723p2_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_103_LTE_LB13), 5180, 5238, CAM_JN1_SET_A_all_723p2_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_103_LTE_LB13), 5239, 5279, CAM_JN1_SET_A_all_774p4_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_104_LTE_LB14), 5280, 5368, CAM_JN1_SET_A_all_774p4_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_104_LTE_LB14), 5369, 5379, CAM_JN1_SET_A_all_723p2_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_107_LTE_LB17), 5730, 5849, CAM_JN1_SET_A_all_723p2_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_108_LTE_LB18), 5850, 5853, CAM_JN1_SET_A_all_723p2_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_108_LTE_LB18), 5854, 5999, CAM_JN1_SET_A_all_774p4_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_109_LTE_LB19), 6000, 6003, CAM_JN1_SET_A_all_774p4_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_109_LTE_LB19), 6004, 6149, CAM_JN1_SET_A_all_723p2_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_110_LTE_LB20), 6150, 6270, CAM_JN1_SET_A_all_774p4_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_110_LTE_LB20), 6271, 6449, CAM_JN1_SET_A_all_723p2_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_111_LTE_LB21), 6450, 6599, CAM_JN1_SET_A_all_723p2_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_115_LTE_LB25), 8040, 8191, CAM_JN1_SET_A_all_723p2_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_115_LTE_LB25), 8192, 8341, CAM_JN1_SET_A_all_774p4_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_115_LTE_LB25), 8342, 8557, CAM_JN1_SET_A_all_723p2_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_115_LTE_LB25), 8558, 8689, CAM_JN1_SET_A_all_774p4_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_116_LTE_LB26), 8690, 8703, CAM_JN1_SET_A_all_723p2_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_116_LTE_LB26), 8704, 8853, CAM_JN1_SET_A_all_774p4_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_116_LTE_LB26), 8854, 9039, CAM_JN1_SET_A_all_723p2_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_118_LTE_LB28), 9210, 9298, CAM_JN1_SET_A_all_774p4_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_118_LTE_LB28), 9299, 9510, CAM_JN1_SET_A_all_723p2_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_118_LTE_LB28), 9511, 9659, CAM_JN1_SET_A_all_774p4_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_119_LTE_LB29), 9660, 9769, CAM_JN1_SET_A_all_774p4_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_120_LTE_LB30), 9770, 9814, CAM_JN1_SET_A_all_774p4_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_120_LTE_LB30), 9815, 9848, CAM_JN1_SET_A_all_793p6_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_120_LTE_LB30), 9849, 9869, CAM_JN1_SET_A_all_723p2_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_122_LTE_LB32), 9920, 9938, CAM_JN1_SET_A_all_774p4_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_122_LTE_LB32), 9939, 10153, CAM_JN1_SET_A_all_723p2_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_122_LTE_LB32), 10154, 10188, CAM_JN1_SET_A_all_793p6_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_122_LTE_LB32), 10189, 10300, CAM_JN1_SET_A_all_774p4_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_122_LTE_LB32), 10301, 10359, CAM_JN1_SET_A_all_723p2_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_124_LTE_LB34), 36200, 36292, CAM_JN1_SET_A_all_723p2_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_124_LTE_LB34), 36293, 36349, CAM_JN1_SET_A_all_774p4_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_128_LTE_LB38), 37750, 37798, CAM_JN1_SET_A_all_774p4_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_128_LTE_LB38), 37799, 38010, CAM_JN1_SET_A_all_723p2_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_128_LTE_LB38), 38011, 38067, CAM_JN1_SET_A_all_793p6_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_128_LTE_LB38), 38068, 38160, CAM_JN1_SET_A_all_774p4_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_128_LTE_LB38), 38161, 38249, CAM_JN1_SET_A_all_723p2_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_129_LTE_LB39), 38250, 38328, CAM_JN1_SET_A_all_774p4_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_129_LTE_LB39), 38329, 38539, CAM_JN1_SET_A_all_723p2_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_129_LTE_LB39), 38540, 38649, CAM_JN1_SET_A_all_774p4_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_130_LTE_LB40), 38650, 38717, CAM_JN1_SET_A_all_723p2_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_130_LTE_LB40), 38718, 38806, CAM_JN1_SET_A_all_774p4_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_130_LTE_LB40), 38807, 38867, CAM_JN1_SET_A_all_793p6_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_130_LTE_LB40), 38868, 39078, CAM_JN1_SET_A_all_723p2_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_130_LTE_LB40), 39079, 39194, CAM_JN1_SET_A_all_774p4_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_130_LTE_LB40), 39195, 39228, CAM_JN1_SET_A_all_793p6_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_130_LTE_LB40), 39229, 39440, CAM_JN1_SET_A_all_723p2_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_130_LTE_LB40), 39441, 39581, CAM_JN1_SET_A_all_774p4_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_130_LTE_LB40), 39582, 39590, CAM_JN1_SET_A_all_793p6_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_130_LTE_LB40), 39591, 39649, CAM_JN1_SET_A_all_723p2_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_131_LTE_LB41), 39650, 39715, CAM_JN1_SET_A_all_774p4_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_131_LTE_LB41), 39716, 39926, CAM_JN1_SET_A_all_723p2_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_131_LTE_LB41), 39927, 39932, CAM_JN1_SET_A_all_793p6_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_131_LTE_LB41), 39933, 40076, CAM_JN1_SET_A_all_774p4_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_131_LTE_LB41), 40077, 40288, CAM_JN1_SET_A_all_723p2_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_131_LTE_LB41), 40289, 40320, CAM_JN1_SET_A_all_793p6_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_131_LTE_LB41), 40321, 40438, CAM_JN1_SET_A_all_774p4_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_131_LTE_LB41), 40439, 40650, CAM_JN1_SET_A_all_723p2_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_131_LTE_LB41), 40651, 40707, CAM_JN1_SET_A_all_793p6_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_131_LTE_LB41), 40708, 40800, CAM_JN1_SET_A_all_774p4_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_131_LTE_LB41), 40801, 41011, CAM_JN1_SET_A_all_723p2_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_131_LTE_LB41), 41012, 41094, CAM_JN1_SET_A_all_793p6_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_131_LTE_LB41), 41095, 41161, CAM_JN1_SET_A_all_774p4_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_131_LTE_LB41), 41162, 41373, CAM_JN1_SET_A_all_723p2_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_131_LTE_LB41), 41374, 41481, CAM_JN1_SET_A_all_793p6_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_131_LTE_LB41), 41482, 41523, CAM_JN1_SET_A_all_774p4_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_131_LTE_LB41), 41524, 41589, CAM_JN1_SET_A_all_723p2_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_132_LTE_LB42), 41590, 41647, CAM_JN1_SET_A_all_793p6_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_132_LTE_LB42), 41648, 41867, CAM_JN1_SET_A_all_723p2_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_132_LTE_LB42), 41868, 41975, CAM_JN1_SET_A_all_774p4_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_132_LTE_LB42), 41976, 42017, CAM_JN1_SET_A_all_793p6_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_132_LTE_LB42), 42018, 42228, CAM_JN1_SET_A_all_723p2_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_132_LTE_LB42), 42229, 42363, CAM_JN1_SET_A_all_774p4_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_132_LTE_LB42), 42364, 42378, CAM_JN1_SET_A_all_793p6_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_132_LTE_LB42), 42379, 42590, CAM_JN1_SET_A_all_723p2_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_132_LTE_LB42), 42591, 42740, CAM_JN1_SET_A_all_774p4_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_132_LTE_LB42), 42741, 42951, CAM_JN1_SET_A_all_723p2_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_132_LTE_LB42), 42952, 43101, CAM_JN1_SET_A_all_774p4_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_132_LTE_LB42), 43102, 43313, CAM_JN1_SET_A_all_723p2_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_132_LTE_LB42), 43314, 43463, CAM_JN1_SET_A_all_774p4_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_132_LTE_LB42), 43464, 43589, CAM_JN1_SET_A_all_723p2_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_138_LTE_LB48), 55240, 55251, CAM_JN1_SET_A_all_774p4_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_138_LTE_LB48), 55252, 55463, CAM_JN1_SET_A_all_723p2_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_138_LTE_LB48), 55464, 55613, CAM_JN1_SET_A_all_774p4_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_138_LTE_LB48), 55614, 55825, CAM_JN1_SET_A_all_723p2_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_138_LTE_LB48), 55826, 55975, CAM_JN1_SET_A_all_774p4_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_138_LTE_LB48), 55976, 56199, CAM_JN1_SET_A_all_723p2_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_138_LTE_LB48), 56200, 56336, CAM_JN1_SET_A_all_774p4_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_138_LTE_LB48), 56337, 56548, CAM_JN1_SET_A_all_723p2_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_138_LTE_LB48), 56549, 56583, CAM_JN1_SET_A_all_793p6_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_138_LTE_LB48), 56584, 56698, CAM_JN1_SET_A_all_774p4_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_138_LTE_LB48), 56699, 56739, CAM_JN1_SET_A_all_723p2_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_156_LTE_LB66), 66436, 66595, CAM_JN1_SET_A_all_723p2_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_156_LTE_LB66), 66596, 66697, CAM_JN1_SET_A_all_793p6_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_156_LTE_LB66), 66698, 66745, CAM_JN1_SET_A_all_774p4_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_156_LTE_LB66), 66746, 66956, CAM_JN1_SET_A_all_723p2_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_156_LTE_LB66), 66957, 67089, CAM_JN1_SET_A_all_793p6_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_156_LTE_LB66), 67090, 67106, CAM_JN1_SET_A_all_774p4_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_156_LTE_LB66), 67107, 67318, CAM_JN1_SET_A_all_723p2_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_156_LTE_LB66), 67319, 67331, CAM_JN1_SET_A_all_774p4_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_156_LTE_LB66), 67332, 67335, CAM_JN1_SET_A_all_793p6_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_161_LTE_LB71), 68586, 68638, CAM_JN1_SET_A_all_793p6_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_161_LTE_LB71), 68639, 68849, CAM_JN1_SET_A_all_723p2_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_161_LTE_LB71), 68850, 68923, CAM_JN1_SET_A_all_774p4_MHZ },
{ CAM_RAT_BAND(CAM_RAT_3_LTE, CAM_BAND_161_LTE_LB71), 68924, 68935, CAM_JN1_SET_A_all_793p6_MHZ },
{ CAM_RAT_BAND(CAM_RAT_4_TDSCDMA, CAM_BAND_051_TDSCDMA_TD1), 0, 0, CAM_JN1_SET_A_all_793p6_MHZ },
{ CAM_RAT_BAND(CAM_RAT_4_TDSCDMA, CAM_BAND_052_TDSCDMA_TD2), 0, 0, CAM_JN1_SET_A_all_793p6_MHZ },
{ CAM_RAT_BAND(CAM_RAT_4_TDSCDMA, CAM_BAND_053_TDSCDMA_TD3), 0, 0, CAM_JN1_SET_A_all_793p6_MHZ },
{ CAM_RAT_BAND(CAM_RAT_4_TDSCDMA, CAM_BAND_054_TDSCDMA_TD4), 0, 0, CAM_JN1_SET_A_all_723p2_MHZ },
{ CAM_RAT_BAND(CAM_RAT_4_TDSCDMA, CAM_BAND_055_TDSCDMA_TD5), 0, 0, CAM_JN1_SET_A_all_793p6_MHZ },
{ CAM_RAT_BAND(CAM_RAT_4_TDSCDMA, CAM_BAND_056_TDSCDMA_TD6), 0, 0, CAM_JN1_SET_A_all_723p2_MHZ },
{ CAM_RAT_BAND(CAM_RAT_5_CDMA, CAM_BAND_061_CDMA_BC0), 0, 0, CAM_JN1_SET_A_all_723p2_MHZ },
{ CAM_RAT_BAND(CAM_RAT_5_CDMA, CAM_BAND_062_CDMA_BC1), 0, 0, CAM_JN1_SET_A_all_723p2_MHZ },
{ CAM_RAT_BAND(CAM_RAT_5_CDMA, CAM_BAND_071_CDMA_BC10), 0, 0, CAM_JN1_SET_A_all_793p6_MHZ },
{ CAM_RAT_BAND(CAM_RAT_7_NR5G, CAM_BAND_260_NR5G_N005), 173800, 175830, CAM_JN1_SET_A_all_774p4_MHZ },
{ CAM_RAT_BAND(CAM_RAT_7_NR5G, CAM_BAND_260_NR5G_N005), 175831, 178380, CAM_JN1_SET_A_all_723p2_MHZ },
{ CAM_RAT_BAND(CAM_RAT_7_NR5G, CAM_BAND_260_NR5G_N005), 178381, 178780, CAM_JN1_SET_A_all_793p6_MHZ },
{ CAM_RAT_BAND(CAM_RAT_7_NR5G, CAM_BAND_263_NR5G_N008), 185000, 185620, CAM_JN1_SET_A_all_723p2_MHZ },
{ CAM_RAT_BAND(CAM_RAT_7_NR5G, CAM_BAND_263_NR5G_N008), 185621, 188150, CAM_JN1_SET_A_all_793p6_MHZ },
{ CAM_RAT_BAND(CAM_RAT_7_NR5G, CAM_BAND_263_NR5G_N008), 188151, 190420, CAM_JN1_SET_A_all_774p4_MHZ },
{ CAM_RAT_BAND(CAM_RAT_7_NR5G, CAM_BAND_263_NR5G_N008), 190421, 191980, CAM_JN1_SET_A_all_723p2_MHZ },
{ CAM_RAT_BAND(CAM_RAT_7_NR5G, CAM_BAND_267_NR5G_N012), 145800, 146120, CAM_JN1_SET_A_all_793p6_MHZ },
{ CAM_RAT_BAND(CAM_RAT_7_NR5G, CAM_BAND_267_NR5G_N012), 146121, 149200, CAM_JN1_SET_A_all_723p2_MHZ },
{ CAM_RAT_BAND(CAM_RAT_7_NR5G, CAM_BAND_275_NR5G_N020), 158200, 160600, CAM_JN1_SET_A_all_774p4_MHZ },
{ CAM_RAT_BAND(CAM_RAT_7_NR5G, CAM_BAND_275_NR5G_N020), 160601, 164180, CAM_JN1_SET_A_all_723p2_MHZ },
{ CAM_RAT_BAND(CAM_RAT_7_NR5G, CAM_BAND_283_NR5G_N028), 151600, 152820, CAM_JN1_SET_A_all_774p4_MHZ },
{ CAM_RAT_BAND(CAM_RAT_7_NR5G, CAM_BAND_283_NR5G_N028), 152821, 154260, CAM_JN1_SET_A_all_793p6_MHZ },
{ CAM_RAT_BAND(CAM_RAT_7_NR5G, CAM_BAND_283_NR5G_N028), 154261, 156980, CAM_JN1_SET_A_all_723p2_MHZ },
{ CAM_RAT_BAND(CAM_RAT_7_NR5G, CAM_BAND_283_NR5G_N028), 156981, 160580, CAM_JN1_SET_A_all_774p4_MHZ },
{ CAM_RAT_BAND(CAM_RAT_7_NR5G, CAM_BAND_326_NR5G_N071), 123400, 124950, CAM_JN1_SET_A_all_793p6_MHZ },
{ CAM_RAT_BAND(CAM_RAT_7_NR5G, CAM_BAND_326_NR5G_N071), 124951, 127760, CAM_JN1_SET_A_all_723p2_MHZ },
{ CAM_RAT_BAND(CAM_RAT_7_NR5G, CAM_BAND_326_NR5G_N071), 127761, 129300, CAM_JN1_SET_A_all_774p4_MHZ },
{ CAM_RAT_BAND(CAM_RAT_7_NR5G, CAM_BAND_326_NR5G_N071), 129301, 130380, CAM_JN1_SET_A_all_793p6_MHZ },
};

static const struct cam_mipi_sensor_mode sensor_s5kjn1_setfile_A_mipi_sensor_mode[] = {
    {
        sensor_s5kjn1_setfile_A_channel,	ARRAY_SIZE(sensor_s5kjn1_setfile_A_channel),
        sensor_s5kjn1_setfile_A_mipi_setting,	ARRAY_SIZE(sensor_s5kjn1_setfile_A_mipi_setting)
    },
};

#endif /* _CAM_SENSOR_ADAPTIVE_MIPI_S5KJN1_H_ */
